componenttools.iterate_timeline_forward_in_expr
===============================================

.. autofunction:: abjad.tools.componenttools.iterate_timeline_forward_in_expr.iterate_timeline_forward_in_expr
